/*
 *    This file is part of MixShark.
 *
 *  MixShark is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  MixShark is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MixShark.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include "bookmarksmanager.h"
#include "application.h"
#include <QFile>
#include <QPair>
#include <QtDebug>

BookmarksManager::BookmarksManager(QObject *parent) :
    QObject(parent)
{
}

QList<Bookmark> BookmarksManager::getBookmarks() const
{
    QList<Bookmark> bookmarks;
    QFile file(app()->dataDirectory()+"/Bookmarks");
    if(file.open(QIODevice::ReadOnly))
    {
        QDataStream in(&file);
        in >> bookmarks;
    }
    file.close();
    return bookmarks;
}

void BookmarksManager::setBookmarks(QList<Bookmark> bookmarks)
{
    QFile file(app()->dataDirectory()+"/Bookmarks");
    if(file.open(QIODevice::ReadWrite))
    {
        file.resize(0);
        QDataStream out(&file);
        out << bookmarks;
    }

    file.close();
    emit bookmarksChanged();
}

void BookmarksManager::addBookmark(const QUrl &url, const QString &title)
{
    QList<Bookmark> bookmarks = getBookmarks();
    QFile file(app()->dataDirectory()+"/Bookmarks");
    if(file.open(QIODevice::ReadWrite))
    {
        bookmarks << Bookmark(url, title);

        file.resize(0);
        QDataStream out(&file);
        out << bookmarks;
    }

    file.close();
    emit bookmarksChanged();
}


