/*
 *    This file is part of MixShark.
 *
 *  MixShark is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  MixShark is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MixShark.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include "bookmarksviewtc.h"
#include "application.h"
#include "bookmarksmanager.h"
#include <QStandardItemModel>
#include <QTreeView>

BookmarksViewTabContent::BookmarksViewTabContent(QWidget *parent) :
    TabContent(parent), model(new QStandardItemModel), view(new QTreeView)
{
    model->setHorizontalHeaderItem(0, new QStandardItem(tr("Title")));
    model->setHorizontalHeaderItem(1, new QStandardItem(tr("URL")));

    view->setModel(model);
    setWidget(view);

    updateTable();
    connect(app()->bookmarksManager(), SIGNAL(bookmarksChanged()), this, SLOT(updateTable()));
    connect(model, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(updateBookmarks()));
}

void BookmarksViewTabContent::updateTable()
{
    model->clear();
    QList<Bookmark> bookmarks = app()->bookmarksManager()->getBookmarks();

    foreach(Bookmark bookmark, bookmarks)
    {
        QList<QStandardItem *> row;
        row << new QStandardItem(bookmark.second) << new QStandardItem(bookmark.first.toString());
        model->appendRow(row);
    }
}

void BookmarksViewTabContent::updateBookmarks()
{
    QList<Bookmark> bookmarks;
    for(int i = 0; i < model->rowCount(); i++)
    {
        QString s = model->index(i, 0).data().toString();
        QString t = model->index(i, 1).data().toString();
        bookmarks.append(Bookmark(t, s));
    }
    app()->bookmarksManager()->setBookmarks(bookmarks);
}
