/*
 *    This file is part of MixShark.
 *
 *  MixShark is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  MixShark is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MixShark.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include "cookiejar.h"
#include "application.h"

#include <QFile>
#include <QDateTime>
#include <QtDebug>

NetworkCookieJar::NetworkCookieJar(QObject *parent) :
    QNetworkCookieJar(parent), file(app()->dataDirectory()+"/Cookies")
{
//    if(app()->settings().value("CookieSaveEnabled", true).toBool() && file.open(QIODevice::ReadOnly))
//    {
//        QList<QNetworkCookie> cookies;
//        while(!file.atEnd())
//        {
//            QList<QNetworkCookie> cookiesLine = QNetworkCookie::parseCookies(file.readLine());

//            foreach(QNetworkCookie cookie, cookiesLine)
//            {
//                    if(cookie.expirationDate() > QDateTime::currentDateTime())
//                            cookies.append(cookiesLine);
//            }
//        }
//        setAllCookies(cookies);
//        file.close();
//    }
}

bool NetworkCookieJar::setCookiesFromUrl(const QList<QNetworkCookie> &cookieList, const QUrl &url)
{
    if(app()->settings().value("CookieSaveEnabled", true).toBool() && file.open(QIODevice::ReadWrite | QIODevice::Text))
    {
        QTextStream out(&file);
        foreach(QNetworkCookie cookie, cookieList)
        {
            if(!cookie.isSessionCookie() && cookie.expirationDate() > QDateTime::currentDateTime())
            {
                QByteArray s = cookie.toRawForm();
                out << QString(s).toStdString().c_str() << '\n';
            }
        }
        file.close();
    }

    if(app()->settings().value("CookiesEnabled", true).toBool())
        return QNetworkCookieJar::setCookiesFromUrl(cookieList, url);
    else
        return false;
}

QList<QNetworkCookie> NetworkCookieJar::cookiesForUrl(const QUrl &url) const
{
    if(app()->settings().value("CookiesEnabled", true).toBool())
        return QNetworkCookieJar::cookiesForUrl(url);
    else
        return QList<QNetworkCookie>();
}
