#include "htmlhighlighter.h"

HtmlHighlighter::HtmlHighlighter(QTextDocument *document)
    : QSyntaxHighlighter(document)
{
    QTextCharFormat entityFormat;
    entityFormat.setForeground(QColor(0, 128, 0));
    setFormatFor(Entity, entityFormat);

    QTextCharFormat tagFormat;
    tagFormat.setForeground(Qt::red);
    setFormatFor(Tag, tagFormat);

    QTextCharFormat commentFormat;
    commentFormat.setForeground(Qt::lightGray);
    commentFormat.setFontItalic(true);
    setFormatFor(Comment, commentFormat);

    QTextCharFormat quoteFormat;
    commentFormat.setForeground(Qt::green);
    setFormatFor(Quote, quoteFormat);
}

void HtmlHighlighter::setFormatFor(Construct construct, const QTextCharFormat &format)
{
    m_formats[construct] = format;
    rehighlight();
}

void HtmlHighlighter::highlightBlock(const QString &text)
{
    int state = previousBlockState();
    int len = text.length();
    int start = 0;
    int pos = 0;
    while(pos < len)
    {
        switch(state)
        {
            case NormalState:
            default:
                while(pos < len)
                {
                    QChar ch = text.at(pos);
                    if(ch == '<')
                    {
                        if(text.mid(pos, 4) == "<!--")
                            state = InComment;
                        else
                            state = InTag;
                        break;
                    }
                    else if(ch == '&')
                    {
                        start = pos;
                        while(pos < len && text.at(pos++) != ';');
                        setFormat(start, pos-start, m_formats[Entity]);
                    }
                    else
                        ++pos;
                }
                break;

            case InComment:
                start = pos;
                while(pos < len)
                {
                    if(text.mid(pos, 3) == "-->")
                    {
                        pos += 3;
                        state = NormalState;
                        break;
                    }
                    else
                        pos++;
                }
                setFormat(start, pos-start,  m_formats[Comment]);
                break;

           case InQuote:
                start = pos;
                while(pos < len)
                {
                    if(text.at(pos) == (char)0x22)
                    {
                        pos++;
                        state = InTag;
                        break;
                    }
                    else
                        pos++;
                }
                setFormat(start, pos-start,  m_formats[Quote]);
                break;

            case InTag:
                QChar quote = QChar::Null;
                start = pos;
                while(pos < len)
                {
                    QChar ch = text.at(pos);
                    if(quote.isNull())
                    {
                        if(ch == '\\' || ch == 0x22 )
                        {
                            state = InQuote;
                            break;
                        }
                        else if (ch == '>')
                        {
                            pos++;
                            state = NormalState;
                            break;
                        }
                    }
                    else if(ch == quote)
                        quote = QChar::Null;
                    pos++;
                }
                setFormat(start, pos-start, m_formats[Tag]);
                break;
        }
    }
    setCurrentBlockState(state);
}
