/*
 *    This file is part of MixShark.
 *
 *  MixShark is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  MixShark is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MixShark.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#ifndef MAINVIEW_H
#define MAINVIEW_H

#include <QTabWidget>
#include <QUrl>

class MainTabBar;
class TabContent;
class MenuButton;
class AddTabButton;
class QMenu;

class MainView : public QTabWidget
{
    Q_OBJECT
public:
    explicit MainView(QWidget *parent = 0);
    MainTabBar *tabBar() const;
    TabContent *currentWidget() const;
    TabContent *widget(int index) const;
    void setMenuButtonMenu(QMenu *newMenu);

signals:
    void currentTabTitleChanged(QString title);
    void currentTabUrlChanged(QUrl url);

public slots:
    TabContent *addWebTab();
    TabContent *addWebTab(QUrl url);
    TabContent *addSettingsTab();
    TabContent *addBookmarksViewTab();
    void removeTab(int index);
    inline void removeTab() { removeTab(currentIndex()); }

private slots:
    void onTabContentTitleChanged(QString title);
    void onCurrentChanged();
    void onCloseTabRequested();
    void updateAddTabButtonPosition();

protected:
    void resizeEvent(QResizeEvent *event);

private:
    MenuButton *menuButton;
    QMenu *menu;
    AddTabButton *m_buttonAddTab;
};

#endif // MAINVIEW_H
