/*
 *    This file is part of MixShark.
 *
 *  MixShark is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  MixShark is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MixShark.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>

class MainView;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

    void initMenuFile();
    void initMenuEdit();
    void initMenuBookmarks();
    void initMenuHelp();

private slots:
    void openFile();
    void saveCurrentPage();
    void undo();
    void redo();
    void cut();
    void copy();
    void paste();
    void selectAll();
    void addCurrentPageToBookmarks();
    void bookmarkTriggered();
    void updateMenuBookmarks();
    void aboutMixShark();

private:
    void enableDwmComposition();

    MainView *mainView;
#ifdef Q_WS_MAC
    QMenuBar *menus;
#else
    QMenu *menus;
#endif
    QMenu *menuFile;
    QAction *actionNewTab;
    QAction *actionCloseTab;
    QAction *actionOpenFile;
    QAction *actionSaveCurrentPage;

    QMenu *menuEdit;
    QAction *actionUndo;
    QAction *actionRedo;
    QAction *actionCut;
    QAction *actionCopy;
    QAction *actionPaste;
    QAction *actionSelectAll;
    QAction *actionAboutMixShark;

    QMenu *menuBookmarks;
    QAction *actionAddCurrentPageToBookmarks;
    QAction *actionManageBookmarks;

    QMenu *menuHelp;
    QAction *actionLoadSettingsDialog;
};

#endif // MAINWINDOW_H
