/*
 *    This file is part of MixShark.
 *
 *  MixShark is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  MixShark is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MixShark.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include "settingstc.h"
#include "ui_settingstc.h"
#include "application.h"
#include <QStyle>
#include <QWebSettings>
#include <QAbstractButton>

SettingsTabContent::SettingsTabContent(QWidget *parent) :
    TabContent(parent),
    ui(new Ui::SettingsTabContent)
{
    setCentralWidget(new QWidget);
    ui->setupUi(centralWidget());
    ui->okButton->setIcon(style()->standardPixmap(QStyle::SP_DialogOkButton));
    connect(ui->okButton, SIGNAL(clicked()), this, SLOT(onOkClicked()));
    loadSettings();
}

SettingsTabContent::~SettingsTabContent()
{
    delete ui;
}

void SettingsTabContent::onOkClicked()
{
    saveSettings();
    emit closeTabRequested();
}

void SettingsTabContent::loadSettings()
{
    ui->homePage->setText(app()->settings().value("HomePage", "").toString());
    ui->enableJavaScript->setChecked(app()->settings().value("JavaScriptEnabled", true).toBool());
    ui->enableJava->setChecked(app()->settings().value("JavaEnabled", true).toBool());
    ui->enablePlugins->setChecked(app()->settings().value("PluginsEnabled", true).toBool());
    ui->enableCookies->setChecked(app()->settings().value("CookiesEnabled", true).toBool());
    ui->enableCookieSave->setChecked(app()->settings().value("CookieSaveEnabled", true).toBool());
    ui->enableProxyUse->setChecked(app()->settings().value("ProxyUseEnabled", false).toBool());
    ui->proxyAddr->setText(app()->settings().value("ProxyAddr", "").toString());
    ui->proxyPort->setValue(app()->settings().value("ProxyPort", 1).toInt());
}

void SettingsTabContent::saveSettings()
{
    app()->settings().setValue("HomePage", QUrl::fromUserInput(ui->homePage->text()).toString());
    app()->settings().setValue("JavaScriptEnabled", ui->enableJavaScript->isChecked());
    app()->settings().setValue("JavaEnabled", ui->enableJava->isChecked());
    app()->settings().setValue("PluginsEnabled", ui->enablePlugins->isChecked());
    app()->settings().setValue("CookiesEnabled", ui->enableCookies->isChecked());
    app()->settings().setValue("CookieSaveEnabled", ui->enableCookieSave->isChecked() && ui->enableCookies->isChecked());
    app()->settings().setValue("ProxyUseEnabled", ui->enableProxyUse->isChecked());
    app()->settings().setValue("ProxyAddr", ui->proxyAddr->text());
    app()->settings().setValue("ProxyPort", ui->proxyPort->value());
}

void SettingsTabContent::restoreDefaultSettings()
{
    app()->settings().setValue("HomePage", "");
    app()->settings().setValue("JavaScriptEnabled", true);
    app()->settings().setValue("JavaEnabled", true);
    app()->settings().setValue("PluginsEnabled", true);
    app()->settings().setValue("CookiesEnabled", true);
    app()->settings().setValue("CookieSaveEnabled", true);
    app()->settings().setValue("ProxyUseEnabled", false);
    app()->settings().setValue("ProxyAddr", "");
    app()->settings().setValue("ProxyPort", 1);
    loadSettings();
}
