/*
 *    This file is part of MixShark.
 *
 *  MixShark is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  MixShark is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MixShark.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#ifndef TABCONTENT_H
#define TABCONTENT_H

#include <QMainWindow>
#include <QUrl>

class QVBoxLayout;
class QTextEdit;
class MainToolBar;
class UrlField;
class ProgressIndicator;
class HtmlHighlighter;

class TabContent : public QMainWindow
{
    Q_OBJECT
public:
    explicit TabContent(QWidget *parent = 0);
    virtual void load(const QUrl &url) = 0;
    virtual QString title() = 0;
    virtual QUrl url() = 0;
    virtual QString data() = 0;
    virtual QIcon icon() = 0;
    inline void setWidget(QWidget *widget) { setCentralWidget(widget); }

    void addNavigationToolBar();

signals:
    void titleChanged(const QString &newTitle);
    void urlChanged(const QUrl &newUrl);
    void loadStarted();
    void loadFinished(bool);
    void dataChanged();
    void addBookmarkRequested(const QUrl &url);
    void savePageAsRequested(const QString &data);
    void showSourceCodeRequested(const QString &data);
    void loadUrlNewTabRequested(const QUrl &url);
    void closeTabRequested();

public slots:
    virtual void back() {}
    virtual void forward() {}
    virtual void reload() {}
    virtual void openActiveLink() {}
    virtual void openActiveLinkNewTab() {}
    virtual void showActiveImage() {}
    virtual void undo() {}
    virtual void redo() {}
    virtual void cut() {}
    virtual void copy() {}
    virtual void paste() {}
    virtual void selectAll() {}
    void showSource();
    void setUrlFieldValue(const QUrl &url);
    void updateSourceCodeEdit();

private slots:
    virtual void onLoadStarted();
    virtual void onLoadFinished();
    void loadUrlFieldContent();
    void requestAddPageToBookmarks();
    void requestSavePageAs();
    void requestShowSourceCode();

protected:
    virtual bool canGoBack() = 0;
    virtual bool canGoForward() = 0;

protected:
    QDockWidget *dockWidgetSourceCode;
    QTextEdit *sourceCodeEdit;
    QAction *actionBack;
    QAction *actionForward;
    QAction *actionReloadOrStop;
    QAction *actionAddPageToBookmarks;
    QAction *actionSavePageAs;
    QAction *actionSelectAll;
    QAction *actionShowSourceCode;

    QAction *actionCut;
    QAction *actionCopy;
    QAction *actionPaste;
    QAction *actionWebSearchTextSelection;
    QAction *actionShowSelectionSourceCode;

    QAction *actionOpenLink;
    QAction *actionOpenLinkNewTab;
    QAction *actionAddLinkToBookmarks;
    QAction *actionSaveLinkAs;
    QAction *actionCopyLinkUrl;
    QAction *actionCopyLinkText;

    QAction *actionShowImage;
    QAction *actionCopyImage;
    QAction *actionCopyImageUrl;
    QAction *actionSaveImageAs;

private:
    MainToolBar *mainToolBar;
    ProgressIndicator *progressIndicator;
    HtmlHighlighter *sourceCodeHighlighter;
};

#endif // TABCONTENT_H
