/*
 *    This file is part of MixShark.
 *
 *  MixShark is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  MixShark is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MixShark.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include "webpage.h"
#include "application.h"
#include "cookiejar.h"
#include "application.h"
#include <QNetworkAccessManager>
#include <QNetworkDiskCache>
#include <QNetworkProxy>

WebPage::WebPage(QObject *parent) :
    QWebPage(parent)
{
    settings()->setMaximumPagesInCache(320);
    settings()->setAttribute(QWebSettings::JavascriptEnabled, app()->settings().value("JavaScriptEnabled", true).toBool());
    settings()->setAttribute(QWebSettings::JavaEnabled, app()->settings().value("JavaEnabled", true).toBool());
    settings()->setAttribute(QWebSettings::PluginsEnabled, app()->settings().value("PluginsEnabled", true).toBool());
    settings()->setAttribute(QWebSettings::DeveloperExtrasEnabled, true);

    networkAccessManager()->setCookieJar(new NetworkCookieJar(this));
    QNetworkDiskCache *cache = new QNetworkDiskCache(this);
    cache->setCacheDirectory(QDesktopServices::storageLocation(QDesktopServices::CacheLocation));
    networkAccessManager()->setCache(cache);

    if(app()->settings().value("ProxyUseEnabled", false).toBool())
    {
        QString proxyAddr = app()->settings().value("ProxyAddr", "").toString();
        int proxyPort = app()->settings().value("ProxyPort", 1).toInt();
        if(!proxyAddr.isEmpty())
        {
            QNetworkProxy proxy;
            proxy.setType(QNetworkProxy::HttpProxy);
            proxy.setHostName(proxyAddr);
            proxy.setPort(proxyPort);
            networkAccessManager()->setProxy(proxy);
        }
    }
}
