/*
 *    This file is part of MixShark.
 *
 *  MixShark is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  MixShark is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MixShark.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include "webview.h"
#include "webpage.h"
#include "webkittc.h"

#include <QMenu>
#include <QContextMenuEvent>
#include <QWebHitTestResult>
#include <QtDebug>

WebView::WebView(QWidget *parent) :
    QWebView(parent)
{
    setPage(new WebPage);
}

void WebView::contextMenuEvent(QContextMenuEvent *event)
{
//    QMenu *contextMenuDefault = qobject_cast<WebKitTabContent *>(parentWidget())->contextMenuDefault;
//    contextMenuDefault->exec(e->globalPos());

    QMenu *menu = new QMenu(this);

    QWebHitTestResult result = page()->mainFrame()->hitTestContent(event->pos());
    if(!result.linkUrl().isEmpty())
    {
        QAction *actionOpenLink = qobject_cast<WebKitTabContent *>(parentWidget())->actionOpenLink;
        QAction *actionOpenLinkNewTab = qobject_cast<WebKitTabContent *>(parentWidget())->actionOpenLinkNewTab;
        actionOpenLink->setProperty("Url", result.linkUrl());
        actionOpenLinkNewTab->setProperty("Url", result.linkUrl());
        menu->addAction(actionOpenLink);
        menu->addAction(actionOpenLinkNewTab);
        menu->addSeparator();
    }
    if(!result.pixmap().isNull())
    {
        QAction *actionShowImage = qobject_cast<WebKitTabContent *>(parentWidget())->actionShowImage;
        actionShowImage->setProperty("ImageUrl", result.imageUrl());
        menu->addAction(actionShowImage);
        menu->addSeparator();
    }
    if(result.isContentSelected())
    {
        if(result.isContentEditable())
            menu->addAction(qobject_cast<WebKitTabContent *>(parentWidget())->actionCut);
        menu->addAction(qobject_cast<WebKitTabContent *>(parentWidget())->actionCopy);
    }
    if(result.isContentEditable())
        menu->addAction(qobject_cast<WebKitTabContent *>(parentWidget())->actionPaste);
    menu->addSeparator();
    // menu->addAction(qobject_cast<WebKitTabContent *>(parentWidget())->actionShowSourceCode); // useless
    menu->addAction(qobject_cast<WebKitTabContent *>(parentWidget())->actionInspectElement);

    menu->exec(event->globalPos());
}

